@@ -7,6 +7,8 @@
 /* Defined if sys/acl.h exists */
 #define HAVE_SYS_ACL_H 1
 
-#define KDE_INSTALL_FULL_LIBEXECDIR_KF "/usr/lib64/libexec/kf5"
+#define KDE_INSTALL_FULL_LIBEXECDIR_KF "/usr/libexec/kf6"
 
-#define KIO_ASSERT_SLAVE_STATES 0
+#define KDE_INSTALL_FULL_KIO_PLUGINDIR "/usr/lib64/qt6/plugins/kf6/kio/"
+
+#define KIO_ASSERT_WORKER_STATES 0
